@@ -11,7 +11,7 @@ use CLDR::Number::Constant qw( $N $M $P $C );
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION      = '0.15';
+our $VERSION      = '0.16';
 our $CLDR_VERSION = '28';
 
 our $DATA = {
@@ -33,8 +33,9 @@ our $DATA = {
             permil => '‰',
             plus => '+',
         },
-        system => {
-            default => 'latn',
+        attr => {
+            min_group => 1,
+            system => 'latn',
         },
     },
     af => {
@@ -80,8 +81,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{RIGHT-TO-LEFT MARK}+",
         },
-        system => {
-            default => 'arab',
+        attr => {
+            system => 'arab',
         },
     },
     'ar-DZ' => {
@@ -93,8 +94,8 @@ our $DATA = {
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
-        system => {
-            default => 'latn',
+        attr => {
+            system => 'latn',
         },
     },
     'ar-EH' => {
@@ -106,8 +107,8 @@ our $DATA = {
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
-        system => {
-            default => 'latn',
+        attr => {
+            system => 'latn',
         },
     },
     'ar-LY' => {
@@ -119,8 +120,8 @@ our $DATA = {
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
-        system => {
-            default => 'latn',
+        attr => {
+            system => 'latn',
         },
     },
     'ar-MA' => {
@@ -132,8 +133,8 @@ our $DATA = {
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
-        system => {
-            default => 'latn',
+        attr => {
+            system => 'latn',
         },
     },
     'ar-TN' => {
@@ -145,8 +146,8 @@ our $DATA = {
             permil => '‰',
             plus => "\N{LEFT-TO-RIGHT MARK}+",
         },
-        system => {
-            default => 'latn',
+        attr => {
+            system => 'latn',
         },
     },
     as => {
@@ -155,8 +156,8 @@ our $DATA = {
             decimal => '#,##,##0.###',
             percent => '#,##,##0%',
         },
-        system => {
-            default => 'beng',
+        attr => {
+            system => 'beng',
         },
     },
     asa => {
@@ -209,6 +210,9 @@ our $DATA = {
             decimal => ',',
             group => ' ',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     bem => {
         pattern => {
@@ -230,6 +234,9 @@ our $DATA = {
             decimal => ',',
             group => ' ',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     bm => {
         pattern => {
@@ -246,8 +253,8 @@ our $DATA = {
         symbol => {
             nan => 'সংখ্যা না',
         },
-        system => {
-            default => 'beng',
+        attr => {
+            system => 'beng',
         },
     },
     br => {
@@ -325,8 +332,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{RIGHT-TO-LEFT MARK}+",
         },
-        system => {
-            default => 'arab',
+        attr => {
+            system => 'arab',
         },
     },
     cs => {
@@ -450,8 +457,8 @@ our $DATA = {
             infinity => 'གྲངས་མེད',
             nan => 'ཨང་མད',
         },
-        system => {
-            default => 'tibt',
+        attr => {
+            system => 'tibt',
         },
     },
     ebu => {
@@ -584,6 +591,9 @@ our $DATA = {
             decimal => ',',
             group => '.',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     'es-419' => {
         pattern => {
@@ -593,6 +603,9 @@ our $DATA = {
             decimal => '.',
             group => ',',
         },
+        attr => {
+            min_group => 1,
+        },
     },
     'es-AR' => {
         pattern => {
@@ -701,6 +714,9 @@ our $DATA = {
             group => ' ',
             minus => '−',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     eu => {
         pattern => {
@@ -737,8 +753,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     ff => {
@@ -1023,6 +1039,9 @@ our $DATA = {
             group => ' ',
             nan => 'არ არის რიცხვი',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     kab => {
         pattern => {
@@ -1141,8 +1160,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     ksb => {
@@ -1232,8 +1251,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     lt => {
@@ -1276,6 +1295,9 @@ our $DATA = {
             group => ' ',
             nan => 'nav skaitlis',
         },
+        attr => {
+            min_group => 3,
+        },
     },
     mas => {
         pattern => {
@@ -1331,8 +1353,8 @@ our $DATA = {
             currency => '¤#,##0.00',
             decimal => '#,##,##0.###',
         },
-        system => {
-            default => 'deva',
+        attr => {
+            system => 'deva',
         },
     },
     ms => {
@@ -1368,8 +1390,9 @@ our $DATA = {
         symbol => {
             nan => 'ဂဏန်းမဟုတ်သော',
         },
-        system => {
-            default => 'mymr',
+        attr => {
+            min_group => 3,
+            system => 'mymr',
         },
     },
     mzn => {
@@ -1381,8 +1404,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     naq => {
@@ -1409,8 +1432,8 @@ our $DATA = {
         pattern => {
             at_least => '{0}+',
         },
-        system => {
-            default => 'deva',
+        attr => {
+            system => 'deva',
         },
     },
     nl => {
@@ -1501,8 +1524,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     pl => {
@@ -1514,6 +1537,9 @@ our $DATA = {
             decimal => ',',
             group => ' ',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     ps => {
         pattern => {
@@ -1527,8 +1553,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     pt => {
@@ -1549,6 +1575,9 @@ our $DATA = {
         symbol => {
             group => ' ',
         },
+        attr => {
+            min_group => 2,
+        },
     },
     qu => {
         pattern => {
@@ -1914,8 +1943,8 @@ our $DATA = {
             minus => "\N{LEFT-TO-RIGHT MARK}-\N{LEFT-TO-RIGHT MARK}",
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     uz => {
@@ -1938,8 +1967,8 @@ our $DATA = {
             permil => '؉',
             plus => "\N{LEFT-TO-RIGHT MARK}+\N{LEFT-TO-RIGHT MARK}",
         },
-        system => {
-            default => 'arabext',
+        attr => {
+            system => 'arabext',
         },
     },
     'uz-Cyrl' => {
