@@ -3,6 +3,7 @@ package CLDR::Number::Role::Base;
 use v5.8.1;
 use utf8;
 use Carp;
+use Scalar::Util qw( looks_like_number );
 use CLDR::Number::Data::Base;
 use CLDR::Number::Data::System;
 
@@ -12,7 +13,7 @@ use Moo::Role;
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 requires qw( BUILD );
 
@@ -62,6 +63,14 @@ has numbering_system => (
     trigger => 1,
 );
 
+has minimum_grouping_digits => (
+    is => 'rw',
+    isa => sub {
+        croak "minimum_grouping_digits '$_[0]' is invalid"
+            if defined $_[0] && !looks_like_number $_[0];
+    },
+);
+
 # TODO: length NYI
 has length => (
     is => 'rw',
@@ -184,6 +193,10 @@ sub _trigger_locale {
     $self->_build_signs(qw{
         decimal_sign group_sign plus_sign minus_sign infinity nan
     });
+
+    $self->_set_unless_init_arg(
+        minimum_grouping_digits => $self->_get_data(attr => 'min_group')
+    );
 }
 
 sub _trigger_numbering_system {
@@ -192,7 +205,7 @@ sub _trigger_numbering_system {
     return if defined $system
            && exists $CLDR::Number::Data::System::DATA->{$system};
 
-    $self->{numbering_system} = $self->_get_data(system => 'default');
+    $self->{numbering_system} = $self->_get_data(attr => 'system');
 }
 
 sub _split_locale {
